@@ -23,6 +23,7 @@ OC.L10N.register(
     "Due date" : "Sperdatum",
     "Description" : "Beskrywing",
     "Comments" : "Kommentare",
+    "Select Date" : "Kies Datum",
     "Modified" : "Gewysig",
     "Created" : "Geskep",
     "Save" : "Stoor",
@@ -30,6 +31,8 @@ OC.L10N.register(
     "Update" : "Werk by",
     "seconds ago" : "sekondes gelede",
     "Shared with you" : "Met u gedeel",
-    "An error occurred" : "'n Fout het voorgekom"
+    "An error occurred" : "'n Fout het voorgekom",
+    "Today" : "Vandag",
+    "Tomorrow" : "Môre"
 },
 "nplurals=2; plural=(n != 1);");
