@@ -27,20 +27,24 @@ OC.L10N.register(
     "Edit" : "Редакция",
     "Title" : "Име",
     "Members" : "Членове",
+    "Upload attachment" : "Качване",
     "Due date" : "Крайна дата",
     "Remove due date" : "Премахни крайната дата",
     "Description" : "Описание",
     "Attachments" : "Прикачени файлове",
     "Comments" : "Коментари",
+    "Select Date" : "Изберете дата",
     "Modified" : "Промяна",
     "Created" : "Създаден",
-    "Upload attachment" : "Качване",
     "Save" : "Запазване",
     "Reply" : "Отговори",
     "Update" : "Обновяване",
     "(group)" : "(група)",
     "seconds ago" : "преди секунди",
     "Shared with you" : "Споделени с вас",
-    "An error occurred" : "Възникна грешка"
+    "An error occurred" : "Възникна грешка",
+    "Today" : "Днес",
+    "Tomorrow" : "Утре",
+    "This week" : "Тази седмица"
 },
 "nplurals=2; plural=(n != 1);");
