@@ -20,6 +20,8 @@ OC.L10N.register(
     "Save" : "Spremi",
     "Update" : "Ažuriraj",
     "Shared with you" : "Shared with you",
+    "Today" : "Danas",
+    "Tomorrow" : "Sutra",
     "Maximum file size of {size} exceeded" : "Maksimalna veličina datoteke prekoračena"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
