@@ -67,6 +67,7 @@ OC.L10N.register(
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "Změny v <strong>aplikaci Deck</strong>",
     "A <strong>comment</strong> was created on a card" : "Na kartě byl vytvořen <strong>komentář</strong>",
+    "Upcoming cards" : "Nadcházející karty",
     "Personal" : "Osobní",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kartu „%s“ na „%s“ vám přiřadil(a) %s.",
     "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} vám přiřadil(a) kartu „%s“ na „%s“.",
@@ -98,8 +99,8 @@ OC.L10N.register(
     "No file uploaded or file size exceeds maximum of %s" : "Nebyl nahrán žádný soubor nebo jeho velikost přesáhla %s",
     "Personal planning and team project organization" : "Osobní plánování a organizování týmového projektu",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck je nástroj cílený na osobní nebo projektové plánování týmů v Kanban stylu, vestavěný v Nextcloud.\n\n\n- 📥 Zadávejte a uspořádávejte své úkoly do karet\n- 📄 Zapisujte si dodatečné poznámky \n- 🔖 Přiřazujte štítky pro ještě lepší organizaci\n- 👥 Sdílejte se svým týmem, přáteli nebo rodinou\n- 🚀 Dostaňte svůj projekt pod kontrolu",
-    "Create new board" : "Vytvořit novou tabuli",
-    "new board" : "nová tabule",
+    "Card details" : "Podrobnosti o kartě",
+    "Add board" : "Přidat tabuli",
     "Select the board to link to a project" : "Vyberte tabuli kterou propojit s projektem",
     "Search by board title" : "Hledat podle názvu tabule",
     "Select board" : "Vybrat tabuli",
@@ -116,11 +117,12 @@ OC.L10N.register(
     "This board is read only" : "Tato tabule je pouze pro čtení",
     "Drop your files to upload" : "Přetáhněte sem soubory, které chcete nahrát",
     "Archived cards" : "Archivované karty",
-    "Add new list" : "Přidat nový seznam",
+    "Add list" : "Přidat seznam",
     "List name" : "Název seznamu",
     "Apply filter" : "Uplatnit filtr",
     "Filter by tag" : "Filtrovat podle příznaků",
     "Filter by assigned user" : "Filtrovat podle uživatele, který je úkolem pověřen",
+    "Unassigned" : "Nepřiřazeno",
     "Filter by due date" : "Filtrovat podle termínu",
     "Overdue" : "Po termínu",
     "Next 24 hours" : "Následujících 24 hodin",
@@ -128,10 +130,13 @@ OC.L10N.register(
     "Next 30 days" : "Příštích 30 dnů",
     "No due date" : "Žádný termín",
     "Clear filter" : "Vyčistit filtr",
+    "Hide archived cards" : "Skrýt archivované karty",
     "Show archived cards" : "Zobrazit archivované karty",
     "Toggle compact mode" : "Vyp/zap. kompaktní režim",
     "Details" : "Podrobnosti",
     "Loading board" : "Načítání tabule",
+    "No lists available" : "Nejsou k dispozici žádné seznamy",
+    "Create a new list to add cards to this board" : "Pro přidání karet na tuto tabuli vytvořte nový seznam",
     "Board not found" : "Tabule nenalezena",
     "Sharing" : "Sdílení",
     "Tags" : "Štítky",
@@ -149,17 +154,23 @@ OC.L10N.register(
     "Can manage" : "Může spravovat",
     "Delete" : "Smazat",
     "Add a new list" : "Přidat nový sloupec",
+    "Archive all cards" : "Archivovat všechny karty",
     "Delete list" : "Smazat seznam",
     "Add card" : "Přidat kartu",
+    "Archive all cards in this list" : "Archivovat všechny karty v tomto seznamu",
     "Add a new card" : "Přidat novou kartu",
+    "Card name" : "Název karty",
     "Edit" : "Upravit",
     "Add a new tag" : "Přidat nový štítek",
     "title and color value must be provided" : "je třeba zadat nadpis a zvolit barvu",
     "Title" : "Nadpis",
     "Members" : "Členové",
+    "Upload attachment" : "Nahrát přílohu",
     "Add this attachment" : "Přidat tuto přílohu",
     "Delete Attachment" : "Smazat přílohu",
     "Restore Attachment" : "Obnovit přílohu",
+    "Open in sidebar view" : "Otevřít v zobrazení v postranním panelu",
+    "Open in bigger view" : "Otevřít ve větším zobrazení",
     "Assign a tag to this card…" : "Přiřadit této kartě štítek…",
     "Assign to users" : "Přiřadit k uživatelům",
     "Assign to users/groups/circles" : "Přiřadit uživatelům/skupinám/okruhům",
@@ -177,9 +188,10 @@ OC.L10N.register(
     "Attachments" : "Přílohy",
     "Comments" : "Komentáře",
     "Choose attachment" : "Zvolte přílohu",
+    "Select Date" : "Vybrat datum",
     "Modified" : "Změněno",
     "Created" : "Vytvořeno",
-    "Upload attachment" : "Nahrát přílohu",
+    "The title cannot be empty." : "Nadpis je třeba vyplnit.",
     "No comments yet. Begin the discussion!" : "Zatím bez komentářů. Zahajte diskuzi!",
     "Save" : "Uložit",
     "The comment cannot be empty." : "Komentář je třeba vyplnit",
@@ -189,22 +201,23 @@ OC.L10N.register(
     "Update" : "Aktualizovat",
     "(group)" : "(skupina)",
     "(circle)" : "(okruh)",
-    "seconds ago" : "před několika sekundami",
     "Assign to me" : "Přiřadit mě",
     "Unassign myself" : "Zrušit přiřazení sobě",
     "Unarchive card" : "Zrušit archivaci karty",
     "Archive card" : "Archivovat kartu",
     "Delete card" : "Smazat kartu",
     "Move card" : "Přesunout kartu",
-    "Card details" : "Podrobnosti o kartě",
     "Move card to another board" : "Přesunout kartu na jinou tabuli",
     "Select a list" : "Vyberte sloupec",
+    "seconds ago" : "před několika sekundami",
     "All boards" : "Všechny tabule",
     "Archived boards" : "Archivované tabule",
     "Shared with you" : "Sdíleno s vámi",
+    "Use modal card view" : "Použít modální zobrazení karty",
+    "Show boards in calendar/tasks" : "Zobrazit tabule v kalendáři/úkolech",
     "Limit deck usage of groups" : "Omezit využití deck na skupiny",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omezení nastavené pro Deck brání uživatelům, kteří nejsou součástí těchto skupin, ve vytváření vlastních tabulí. Nicméně i tak ale pořád budou moci pracovat na tabulích, které jsou jim nasdíleny.",
-    "New board title" : "Název nové tabule",
+    "Board name" : "Název tabule",
     "Edit board" : "Upravit tabuli",
     "Clone board " : "Klonovat tabuli ",
     "Unarchive board " : "Vrátit tabuli zpět z archivu ",
@@ -215,6 +228,13 @@ OC.L10N.register(
     "An error occurred" : "Došlo k chybě",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Opravdu chcete tabuly {title} smazat? Toto smaže veškerá data této tabule.",
     "Delete the board?" : "Smazat tabuli?",
+    "Loading filtered view" : "Načítání filtrovaného pohledu",
+    "Today" : "Dnes",
+    "Tomorrow" : "Zítra",
+    "This week" : "Tento týden",
+    "No due" : "Žádný termín",
+    "No upcoming cards" : "Žádné nadcházející karty",
+    "upcoming cards" : "nadcházející karty",
     "Link to a board" : "Propojit s tabulí",
     "Link to a card" : "Propojit s kartou",
     "Something went wrong" : "Něco se pokazilo",
