@@ -16,11 +16,13 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
     "No file was uploaded" : "Ingen fil uploadet",
     "Missing a temporary folder" : "Manglende midlertidig mappe.",
-    "Create new board" : "Opret ny liste",
+    "Add board" : "Tilføj liste",
     "Cancel" : "Annullér",
     "File already exists" : "Fil findes allerede",
     "Do you want to overwrite it?" : "Vil du overskrive den?",
     "Drop your files to upload" : "Drop dine filer for at uploade",
+    "Add list" : "Tilføj liste",
+    "Hide archived cards" : "Skjul arkiverede kort",
     "Show archived cards" : "Vis arkiverede kort",
     "Details" : "Detaljer",
     "Sharing" : "Deling",
@@ -34,28 +36,31 @@ OC.L10N.register(
     "Edit" : "Redigér",
     "Title" : "Titel",
     "Members" : "Medlemmer",
+    "Upload attachment" : "Upload vedhæftning",
     "Due date" : "Forfaldsdato",
     "Remove due date" : "Fjern forfaldsdato",
     "Description" : "Beskrivelse",
     "Formatting help" : "Hjælp til formatering",
     "Attachments" : "Vedhæftede filer",
     "Comments" : "Kommentarer",
+    "Select Date" : "Vælg dato",
     "Modified" : "Ændret",
     "Created" : "Oprettet",
-    "Upload attachment" : "Upload vedhæftning",
     "Save" : "Gem",
     "Reply" : "Besvar",
     "Update" : "Opdatér",
     "(group)" : "(gruppe)",
-    "seconds ago" : "sekunder siden",
     "Archive card" : "Arkivér kort",
     "Delete card" : "Slet kort",
     "Move card" : "Flyt kort",
+    "seconds ago" : "sekunder siden",
     "Archived boards" : "Arkiverede lister",
     "Shared with you" : "Shared with you",
-    "New board title" : "Ny titel på liste",
     "Edit board" : "Rediger liste",
     "Board details" : "Liste detaljer",
-    "An error occurred" : "Der var en fejl"
+    "An error occurred" : "Der var en fejl",
+    "Today" : "I dag",
+    "Tomorrow" : "I morgen",
+    "This week" : "Denne uge"
 },
 "nplurals=2; plural=(n != 1);");
