@@ -15,11 +15,11 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
     "No file was uploaded" : "No se cargó el archivo",
     "Missing a temporary folder" : "Falta una carpeta temporal",
-    "Create new board" : "Crear un nuevo tablero",
     "Cancel" : "Cancelar",
     "File already exists" : "El archivo ya existe",
     "Do you want to overwrite it?" : "¿Deseas sobre escribirlo?",
     "Filter by tag" : "Filtrar por etiqueta",
+    "Hide archived cards" : "Ocultar tarjetas archivadas",
     "Show archived cards" : "Mostrar tarjetas archivadas",
     "Details" : "Detalles",
     "Sharing" : "Compartiendo",
@@ -32,6 +32,7 @@ OC.L10N.register(
     "Edit" : "Editar",
     "Title" : "Título",
     "Members" : "Miembros",
+    "Upload attachment" : "Cargar adjunto",
     "Due date" : "Fecha de vencimiento",
     "Remove due date" : "Eliminar fecha de expiración",
     "Description" : "Descripción",
@@ -39,7 +40,6 @@ OC.L10N.register(
     "Comments" : "Comentarios",
     "Modified" : "Modificado",
     "Created" : "Creado",
-    "Upload attachment" : "Cargar adjunto",
     "Save" : "Guardar",
     "Reply" : "Responder",
     "Update" : "Actualizar",
@@ -47,8 +47,10 @@ OC.L10N.register(
     "seconds ago" : "hace segundos",
     "Archived boards" : "Tableros archivados",
     "Shared with you" : "Compartido con usted",
-    "New board title" : "Nuevo título del tablero",
     "Edit board" : "Editar el tablero",
-    "Board details" : "Detalles del tablero"
+    "Board details" : "Detalles del tablero",
+    "Today" : "Hoy",
+    "Tomorrow" : "Mañana",
+    "This week" : "Esta semana"
 },
 "nplurals=2; plural=(n != 1);");
