@@ -12,8 +12,8 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido sobrepasa el valor MAX_FILE_SIZE especificada en el formulario HTML",
     "No file was uploaded" : "No se subió ningún archivo ",
     "Missing a temporary folder" : "Falta un directorio temporal",
-    "Create new board" : "Crear un nuevo tablero",
     "Cancel" : "Cancelar",
+    "Hide archived cards" : "Ocultar tarjetas archivadas",
     "Show archived cards" : "Mostrar tarjetas archivadas",
     "Details" : "Detalles",
     "Sharing" : "Compartiendo",
@@ -30,6 +30,7 @@ OC.L10N.register(
     "Formatting help" : "Ayuda de formato",
     "Attachments" : "Adjuntos",
     "Comments" : "Comentarios",
+    "Select Date" : "Seleccionar fecha",
     "Modified" : "Modificado",
     "Created" : "Creado",
     "Save" : "Guardar",
@@ -38,8 +39,10 @@ OC.L10N.register(
     "(group)" : "(grupo)",
     "seconds ago" : "segundos",
     "Shared with you" : "Compartido con usted",
-    "New board title" : "Nuevo título de tablero",
     "Board details" : "Detalles del tablero",
-    "An error occurred" : "Ocurrió un error"
+    "An error occurred" : "Ocurrió un error",
+    "Today" : "Hoy",
+    "Tomorrow" : "Mañana",
+    "This week" : "Esta semana"
 },
 "nplurals=2; plural=(n != 1);");
