@@ -19,11 +19,11 @@ OC.L10N.register(
     "Missing a temporary folder" : "Falta una carpeta temporal",
     "Could not write file to disk" : "No fue posible escribir a disco",
     "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
-    "Create new board" : "Crear un nuevo tablero",
     "Cancel" : "Cancelar",
     "File already exists" : "El archivo ya existe",
     "Do you want to overwrite it?" : "¿Deseas sobre escribirlo?",
     "Filter by tag" : "Filtrar por etiqueta",
+    "Hide archived cards" : "Ocultar tarjetas archivadas",
     "Show archived cards" : "Mostrar tarjetas archivadas",
     "Details" : "Detalles",
     "Sharing" : "Compartiendo",
@@ -36,6 +36,7 @@ OC.L10N.register(
     "Edit" : "Editar",
     "Title" : "Título",
     "Members" : "Miembros",
+    "Upload attachment" : "Cargar adjunto",
     "Due date" : "Fecha de vencimiento",
     "Remove due date" : "Eliminar fecha de expiración",
     "Description" : "Descripción",
@@ -44,7 +45,6 @@ OC.L10N.register(
     "Comments" : "Comentarios",
     "Modified" : "Modificado",
     "Created" : "Creado",
-    "Upload attachment" : "Cargar adjunto",
     "Save" : "Guardar",
     "Reply" : "Responder",
     "Update" : "Actualizar",
@@ -52,9 +52,11 @@ OC.L10N.register(
     "seconds ago" : "hace segundos",
     "Archived boards" : "Tableros archivados",
     "Shared with you" : "Compartido con usted",
-    "New board title" : "Nuevo título del tablero",
     "Edit board" : "Editar el tablero",
     "Board details" : "Detalles del tablero",
-    "An error occurred" : "Ha ocurrido un error"
+    "An error occurred" : "Ha ocurrido un error",
+    "Today" : "Hoy",
+    "Tomorrow" : "Mañana",
+    "This week" : "Esta semana"
 },
 "nplurals=2; plural=(n != 1);");
