@@ -38,8 +38,8 @@ OC.L10N.register(
     "Could not write file to disk" : "عدم موفقیت در نوشتن پرونده روی حافظه",
     "A PHP extension stopped the file upload" : "یک افزونه پی‌اچ‌پی مانع بارگذاری پرونده شد",
     "No file uploaded or file size exceeds maximum of %s" : "پرونده‌ای بارگذاری نشد و یا حجم پرونده بیش از بیشینه مجاز %s بود",
-    "Create new board" : "ایجاد تختهٔ جدید",
-    "new board" : "تختهٔ جدید",
+    "Card details" : "جزئیات کارت",
+    "Add board" : "تخته را اضافه کنید",
     "Select the board to link to a project" : "تخته‌ای را برای ایجاد پیوند با یک پروژه انتخاب کنید",
     "Search by board title" : "جستجو بر اساس عنوان تخته",
     "Select board" : "انتخاب تخته",
@@ -56,7 +56,7 @@ OC.L10N.register(
     "This board is read only" : "تخته، فقط خواندنی است",
     "Drop your files to upload" : "برای بارگذاری، پرونده‌ها را اینجا رها کنید",
     "Archived cards" : "کارت‌های بایگانی‌شده",
-    "Add new list" : "افزودن فهرست جدید",
+    "Add list" : "افزودن فهرست",
     "List name" : "نام فهرست",
     "Apply filter" : "اعمال پالایه",
     "Filter by tag" : "پالایش برحسب برچسب",
@@ -93,6 +93,7 @@ OC.L10N.register(
     "title and color value must be provided" : "نام و رنگ باید مشخص شود",
     "Title" : "عنوان",
     "Members" : "اعضا",
+    "Upload attachment" : "بارگذاری پیوست",
     "Add this attachment" : "افزودن این پیوست",
     "Delete Attachment" : "حذف پیوست",
     "Restore Attachment" : "بازیابی پیوست",
@@ -107,9 +108,9 @@ OC.L10N.register(
     "Attachments" : "پیوست‌ها",
     "Comments" : "نظرات",
     "Choose attachment" : "انتخاب پیوست",
+    "Select Date" : "تاریخ را انتخاب کنید",
     "Modified" : "تغییر یافته",
     "Created" : "ایجاد شده",
-    "Upload attachment" : "بارگذاری پیوست",
     "No comments yet. Begin the discussion!" : "هنوز نظری وجود ندارد. بحثی را آغاز کنید!",
     "Save" : "ذخیره",
     "The comment cannot be empty." : "نظر نمی‌تواند خالی باشد.",
@@ -119,17 +120,18 @@ OC.L10N.register(
     "Update" : "به‌روزرسانی",
     "(group)" : "(گروه)",
     "(circle)" : "(حلقه)",
-    "seconds ago" : "ثانیه‌هایی پیش",
     "Archive card" : "کارت بایگانی",
     "Delete card" : "حذف کارت",
     "Move card" : "انتقال کارت",
-    "Card details" : "جزئیات کارت",
     "Move card to another board" : "انتقال کارت به تخته‌ای دیگر",
+    "seconds ago" : "ثانیه‌هایی پیش",
     "All boards" : "همه تخته‌ها",
     "Archived boards" : "تخته‌های بایگانی شده",
     "Shared with you" : "با شما به اشتراک گذاشته شده است",
-    "New board title" : "عنوان تختهٔ جدید",
     "Edit board" : "ویرایش تخته",
-    "An error occurred" : "خطایی روی داد"
+    "An error occurred" : "خطایی روی داد",
+    "Today" : "Today",
+    "Tomorrow" : "فردا",
+    "This week" : "این هفته"
 },
 "nplurals=2; plural=(n > 1);");
