@@ -55,8 +55,8 @@ OC.L10N.register(
     "A PHP extension stopped the file upload" : "הרחבת PHP עצרה את העלאת הקובץ",
     "No file uploaded or file size exceeds maximum of %s" : "לא הועלה אף קובץ או שגודל הקובץ חרג מהסף המרבי של %s",
     "Personal planning and team project organization" : "ארגון אישי וקבוצתי של מיזמים",
-    "Create new board" : "יצירת לוח חדש",
-    "new board" : "לוח חדש",
+    "Card details" : "פרטי הכרטיס",
+    "Add board" : "הוספת לוח",
     "Select the board to link to a project" : "נא לבחור את הלוח לקישור למיזם",
     "Search by board title" : "חיפוש לפי כותרת לו",
     "Select board" : "בחירת לוח",
@@ -73,7 +73,7 @@ OC.L10N.register(
     "This board is read only" : "הלוח הזה הוא לקריאה בלבד",
     "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
     "Archived cards" : "כרטיסים בארכיון",
-    "Add new list" : "הוספת רשימה חדשה",
+    "Add list" : "הוספת רשימה",
     "List name" : "שם הרשימה",
     "Apply filter" : "החלת מסנן",
     "Filter by tag" : "סינון לפי תגית",
@@ -85,6 +85,7 @@ OC.L10N.register(
     "Next 30 days" : "ב־30 הימים הבאים",
     "No due date" : "ללא תאריך יעד",
     "Clear filter" : "מחיקת מסנן",
+    "Hide archived cards" : "הסתרת כרטיסים בארכיון",
     "Show archived cards" : "הצגת כרטיסים בארכיון",
     "Toggle compact mode" : "החלפת מצב חסכוני",
     "Details" : "פרטים",
@@ -113,6 +114,7 @@ OC.L10N.register(
     "title and color value must be provided" : "יש לספק כותרת וערך צבע",
     "Title" : "תפקיד",
     "Members" : "חברים",
+    "Upload attachment" : "העלאת קבצים מצורפים",
     "Add this attachment" : "הוספת קובץ מצורף זה",
     "Delete Attachment" : "מחיקת קובץ מצורף",
     "Restore Attachment" : "שחזור קובץ מצורף",
@@ -133,9 +135,9 @@ OC.L10N.register(
     "Attachments" : "קבצים מצורפים",
     "Comments" : "תגובות",
     "Choose attachment" : "בחירת קובץ מצורף",
+    "Select Date" : "בחירת תאריך",
     "Modified" : "מועד שינוי",
     "Created" : "מועד היצירה",
-    "Upload attachment" : "העלאת קבצים מצורפים",
     "No comments yet. Begin the discussion!" : "אין עדיין הערות. אפשר להתחיל לדון!",
     "Save" : "שמור",
     "The comment cannot be empty." : "ההערה לא יכולה להיות ריקה.",
@@ -145,20 +147,18 @@ OC.L10N.register(
     "Update" : "עדכון",
     "(group)" : "(קבוצה)",
     "(circle)" : "(מעגל)",
-    "seconds ago" : "לפני מספר שניות",
     "Assign to me" : "הקצאה אלי",
     "Unarchive card" : "הוצאת הכרטיס מהארכיון",
     "Archive card" : "העברת כרטיס לארכיון",
     "Delete card" : "מחיקת כרטיס לארכיון",
     "Move card" : "העברת כרטיס",
-    "Card details" : "פרטי הכרטיס",
     "Move card to another board" : "העברת כרטיס ללוח אחר",
+    "seconds ago" : "לפני מספר שניות",
     "All boards" : "כל הלוחות",
     "Archived boards" : "לוחות שנשמרו בארכיון",
     "Shared with you" : "משותף אתך",
     "Limit deck usage of groups" : "הגבלת השימוש בחבילה לקבוצות",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "הגבלת חבילה תחסום משתמשים שאינם חלק מקבוצות אלו מיצירת לוחות משלהם. משתמשים עדיין יוכלו לעבור על לוחות ששותפו אתם.",
-    "New board title" : "כותרת לוח חדשה",
     "Edit board" : "עריכת לוח",
     "Clone board " : "שכפול לוח",
     "Unarchive board " : "הוצאת הלוח מהארכיון",
@@ -169,6 +169,9 @@ OC.L10N.register(
     "An error occurred" : "אירעה שגיאה",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "למחוק את הלוח {title}? פעולה זו תמחק את כל הנתונים של הלוח הזה.",
     "Delete the board?" : "למחוק את הלוח הזה?",
+    "Today" : "היום",
+    "Tomorrow" : "מחר",
+    "This week" : "השבוע",
     "Link to a board" : "קישור ללוח",
     "Link to a card" : "קישור לכרטיס",
     "Something went wrong" : "משהו השתבש",
