@@ -98,8 +98,8 @@ OC.L10N.register(
     "No file uploaded or file size exceeds maximum of %s" : "ファイルがアップロードされていないか、ファイルサイズが最大 %s を超えています",
     "Personal planning and team project organization" : "個人的な計画とチームのプロジェクト編成",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合した、チームの個人計画とプロジェクトの組織化を目的としたカンバンスタイルの組織ツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 マークダウンで追加のメモを書き留めます\n- 🔖 より良い組織のためにラベルを割り当てる\n- 👥 あなたのチーム、友人、家族と共有する\n- 📎 ファイルを添付してマークダウンの説明に埋め込む\n- 💬 コメントを使ってあなたのチームと話し合う\n- ⚡ アクティビティの流れの変化を追跡する\n- 🚀 プロジェクトを整理する",
-    "Create new board" : "新しいボードを作成",
-    "new board" : "新しいボード",
+    "Card details" : "カード詳細",
+    "Add board" : "ボードを追加",
     "Select the board to link to a project" : "プロジェクトにリンクするボードを選択",
     "Search by board title" : "ボードのタイトルで検索",
     "Select board" : "ボードを選択",
@@ -116,11 +116,12 @@ OC.L10N.register(
     "This board is read only" : "このボードは読み込みのみです",
     "Drop your files to upload" : "アップロードするファイルをドロップしてください",
     "Archived cards" : "カードをアーカイブ",
-    "Add new list" : "新しいリストを追加",
+    "Add list" : "リストを追加",
     "List name" : "リスト名",
     "Apply filter" : "フィルターを適用",
     "Filter by tag" : "タグによるフィルター",
     "Filter by assigned user" : "割当ユーザーでフィルター",
+    "Unassigned" : "未割り当て",
     "Filter by due date" : "期限でフィルター",
     "Overdue" : "期限超過",
     "Next 24 hours" : "次の24時間",
@@ -128,6 +129,7 @@ OC.L10N.register(
     "Next 30 days" : "次の30日間",
     "No due date" : "期限なし",
     "Clear filter" : "フィルターをクリア",
+    "Hide archived cards" : "アーカイブされたカードを非表示にする",
     "Show archived cards" : "アーカイブされたカードを表示する",
     "Toggle compact mode" : "コンパクトモードの切り替え",
     "Details" : "詳細",
@@ -157,6 +159,7 @@ OC.L10N.register(
     "title and color value must be provided" : "タイトルと色の値を指定する必要があります",
     "Title" : "タイトル",
     "Members" : "メンバー",
+    "Upload attachment" : "添付ファイルをアップロードする",
     "Add this attachment" : "この添付ファイルを追加",
     "Delete Attachment" : "添付ファイルを削除",
     "Restore Attachment" : "添付ファイルを復元",
@@ -177,9 +180,9 @@ OC.L10N.register(
     "Attachments" : "添付ファイル",
     "Comments" : "コメント",
     "Choose attachment" : "添付ファイルを選択",
+    "Select Date" : "日付を選択",
     "Modified" : "更新日時",
     "Created" : "作成時刻",
-    "Upload attachment" : "添付ファイルをアップロードする",
     "No comments yet. Begin the discussion!" : "まだコメントはありません。議論を始めましょう！",
     "Save" : "保存",
     "The comment cannot be empty." : "コメントを空にすることはできません。",
@@ -189,22 +192,20 @@ OC.L10N.register(
     "Update" : "更新",
     "(group)" : "(グループ)",
     "(circle)" : "(サークル)",
-    "seconds ago" : "数秒前",
     "Assign to me" : "自分に割り当てる",
     "Unassign myself" : "自分への割り当てを解除",
     "Unarchive card" : "カードのアーカイブを解除する",
     "Archive card" : "カードをアーカイブ",
     "Delete card" : "カードを削除する",
     "Move card" : "カードの移動",
-    "Card details" : "カード詳細",
     "Move card to another board" : "カードを他のボードに移動",
     "Select a list" : "リストを選択",
+    "seconds ago" : "数秒前",
     "All boards" : "すべてのボード",
     "Archived boards" : "アーカイブ済みのボード",
     "Shared with you" : "あなたと共有済み",
     "Limit deck usage of groups" : "デッキの使用をグループに制限",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "デッキ作成制限は、設定したグループに非所属のユーザーがボードを作成できないようにします。非所属ユーザーは共有されているボードでのみ作業できます。",
-    "New board title" : "新しいボードのタイトル",
     "Edit board" : "ボードを編集",
     "Clone board " : "ボードを複製",
     "Unarchive board " : "ボードのアーカイブを解除",
@@ -215,6 +216,9 @@ OC.L10N.register(
     "An error occurred" : "エラーが発生しました",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "このボード{title}を削除してもよろしいですか？この操作はこのボードのデータすべてを削除します。",
     "Delete the board?" : "ボードを削除しますか？",
+    "Today" : "今日",
+    "Tomorrow" : "明日",
+    "This week" : "今週",
     "Link to a board" : "ボードへのリンク",
     "Link to a card" : "カードへリンク",
     "Something went wrong" : "何かがおかしいです",
