@@ -15,11 +15,11 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
     "No file was uploaded" : "ფაილი არ აიტვირთა",
     "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
-    "Create new board" : "ახალი დაფის შექმნა",
     "Cancel" : "უარყოფა",
     "File already exists" : "ფაილი უკვე არსებობს",
     "Do you want to overwrite it?" : "გსურთ მისი გადაწერა?",
     "Filter by tag" : "ფილტრი ტეგებით",
+    "Hide archived cards" : "არქივირებული ბარათების დამალვა",
     "Show archived cards" : "არქივირებული ბარათების ჩვენება",
     "Details" : "დეტალები",
     "Sharing" : "გაზიარება",
@@ -32,6 +32,7 @@ OC.L10N.register(
     "Edit" : "შეცვლა",
     "Title" : "სათაური",
     "Members" : "წევრები",
+    "Upload attachment" : "დანართის ატვირთვა",
     "Due date" : "დროისთვის",
     "Remove due date" : "მოაშორეთ დანიშნულების დრო",
     "Description" : "აღწერა",
@@ -39,7 +40,6 @@ OC.L10N.register(
     "Comments" : "კომენტარები",
     "Modified" : "შეიცვალა",
     "Created" : "შექმნილია",
-    "Upload attachment" : "დანართის ატვირთვა",
     "Save" : "შენახვა",
     "Reply" : "პასუხი",
     "Update" : "განახლება",
@@ -47,8 +47,10 @@ OC.L10N.register(
     "seconds ago" : "წამის წინ",
     "Archived boards" : "არქივირებული დაფები",
     "Shared with you" : "გაზიარებული თქვენთან",
-    "New board title" : "ახალი დაფის სახელი",
     "Edit board" : "დაფის შეცვლა",
-    "Board details" : "დაფის დეტალები"
+    "Board details" : "დაფის დეტალები",
+    "Today" : "დღეს",
+    "Tomorrow" : "ხვალ",
+    "This week" : "ამ კვირაში"
 },
 "nplurals=2; plural=(n!=1);");
