@@ -14,6 +14,7 @@ OC.L10N.register(
     "Title" : "ಶೀರ್ಷಿಕೆ",
     "Modified" : "﻿ಬದಲಾಯಿಸಿದ",
     "Save" : "﻿ಉಳಿಸಿ",
-    "Shared with you" : "Shared with you"
+    "Shared with you" : "Shared with you",
+    "Today" : "Today"
 },
 "nplurals=2; plural=(n > 1);");
