@@ -22,8 +22,8 @@ OC.L10N.register(
     "Missing a temporary folder" : "임시 폴더 없음",
     "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
     "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
-    "Create new board" : "새 게시판 만들기",
-    "new board" : "새로운 보드",
+    "Card details" : "카드 세부사항",
+    "Add board" : "보드 추가",
     "Search by board title" : "보드 제목으로 검색",
     "Select board" : "보드 선택",
     "Select the card to link to a project" : "카드를 선택해 프로젝트에 연결",
@@ -38,17 +38,19 @@ OC.L10N.register(
     "This board is read only" : "읽기 전용 보드",
     "Drop your files to upload" : "업로드를 하려면 파일을 올리시오.",
     "Archived cards" : "보관된 카드들",
-    "Add new list" : "새로운 리스트 추가",
+    "Add list" : "목록 추가",
     "List name" : "리스트 추가",
     "Apply filter" : "필터링 적용",
     "Filter by tag" : "태그로 필터링",
     "Filter by assigned user" : "지정된 사용자로 필터링",
+    "Unassigned" : "할당되지 않음",
     "Filter by due date" : "기한으로 필터링",
     "Overdue" : "기한 넘김",
     "Next 24 hours" : "다음 24시간",
     "Next 7 days" : "다음 7일 동안",
     "Next 30 days" : "다음 30일 동안",
     "No due date" : "기한 없음",
+    "Hide archived cards" : "보관된 카드 숨기기",
     "Show archived cards" : "보관된 카드 보기",
     "Details" : "세부사항",
     "Sharing" : "공유",
@@ -64,33 +66,35 @@ OC.L10N.register(
     "Edit" : "편집",
     "Title" : "직위",
     "Members" : "구성원",
+    "Upload attachment" : "첨부 파일 업로드",
     "Due date" : "만료 날짜",
     "Remove due date" : "만료 날짜 삭제",
     "Description" : "설명",
     "Formatting help" : "서식 도움말",
     "Attachments" : "첨부파일",
     "Comments" : "댓글",
+    "Select Date" : "날짜 선택",
     "Modified" : "수정한 날짜",
     "Created" : "생성됨",
-    "Upload attachment" : "첨부 파일 업로드",
     "Save" : "저장",
     "Reply" : "답장",
     "Update" : "업데이트",
     "(group)" : "(그룹)",
-    "seconds ago" : "초 전",
     "Archive card" : "보관 카드",
     "Delete card" : "카드 삭제",
     "Move card" : "카드 이동",
-    "Card details" : "카드 세부사항",
+    "seconds ago" : "초 전",
     "All boards" : "모든 보드",
     "Archived boards" : "보관된 게시판",
     "Shared with you" : "나와 공유됨",
-    "New board title" : "새 게시판 제목",
     "Edit board" : "게시판 편집",
     "Board details" : "게시판 정보",
     "An error occurred" : "오류가 발생함",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "정말로 보드 {title}을 지우시겠습니까? 보드의 모든 데이터가 삭제됩니다.",
     "Delete the board?" : "보드를 삭제합니까?",
+    "Today" : "오늘",
+    "Tomorrow" : "내일",
+    "This week" : "이번 주",
     "Something went wrong" : "잘못된 접근"
 },
 "nplurals=1; plural=0;");
