@@ -22,6 +22,8 @@ OC.L10N.register(
     "Reply" : "Äntwerten",
     "Update" : "Update",
     "seconds ago" : "Sekonnen hier",
-    "Shared with you" : "Mat dir gedeelt"
+    "Shared with you" : "Mat dir gedeelt",
+    "Today" : "Haut",
+    "Tomorrow" : "Muer"
 },
 "nplurals=2; plural=(n != 1);");
