@@ -71,8 +71,8 @@ OC.L10N.register(
     "A PHP extension stopped the file upload" : "PHP plėtinys sustabdė failo įkėlimą",
     "No file uploaded or file size exceeds maximum of %s" : "Neįkeltas joks failas arba failo dydis viršija maksimalų %s dydį",
     "Personal planning and team project organization" : "Asmeninis planavimas ir komandinių projektų organizavimas",
-    "Create new board" : "Sukurti naują lentą",
-    "new board" : "nauja lenta",
+    "Card details" : "Išsamiau apie kortelę",
+    "Add board" : "Pridėti lentą",
     "Select the board to link to a project" : "Pasirinkite lentą, kurią susieti su projektu",
     "Search by board title" : "Ieškoti pagal lentos pavadinimą",
     "Select board" : "Pasirinkti lentą",
@@ -88,7 +88,7 @@ OC.L10N.register(
     "Keep existing file" : "Palikti esamą failą",
     "This board is read only" : "Ši lenta yra tik skaitymui",
     "Archived cards" : "Archyvuotos kortelės",
-    "Add new list" : "Pridėti naują sąrašą",
+    "Add list" : "Pridėti sąrašą",
     "List name" : "Sąrašo pavadinimas",
     "Apply filter" : "Taikyti filtrą",
     "Filter by tag" : "Filtruoti pagal žymę",
@@ -100,6 +100,7 @@ OC.L10N.register(
     "Next 30 days" : "Artimiausios 30 dienų",
     "No due date" : "Be galutinio termino",
     "Clear filter" : "Išvalyti filtrą",
+    "Hide archived cards" : "Slėpti archyvuotas korteles",
     "Show archived cards" : "Rodyti archyvuotas korteles",
     "Toggle compact mode" : "Perjungti kompaktišką veikseną",
     "Details" : "Išsamiau",
@@ -128,6 +129,7 @@ OC.L10N.register(
     "title and color value must be provided" : "privalo būti pateiktos pavadinimo ir spalvos reikšmės",
     "Title" : "Pavadinimas",
     "Members" : "Nariai",
+    "Upload attachment" : "Įkelti priedą",
     "Add this attachment" : "Pridėti šį priedą",
     "Delete Attachment" : "Ištrinti priedą",
     "Restore Attachment" : "Atkurti priedą",
@@ -148,9 +150,9 @@ OC.L10N.register(
     "Attachments" : "Priedai",
     "Comments" : "Komentarai",
     "Choose attachment" : "Pasirinkite priedą",
+    "Select Date" : "Pasirinkti datą",
     "Modified" : "Pakeistas",
     "Created" : "Sukurta",
-    "Upload attachment" : "Įkelti priedą",
     "No comments yet. Begin the discussion!" : "Kol kas komentarų nėra. Pradėkite diskusiją!",
     "Save" : "Įrašyti",
     "The comment cannot be empty." : "Komentaras negali būti tuščias.",
@@ -159,18 +161,16 @@ OC.L10N.register(
     "Update" : "Atnaujinti",
     "(group)" : "(grupė)",
     "(circle)" : "(ratas)",
-    "seconds ago" : "prieš keletą sekundžių",
     "Assign to me" : "Priskirti sau",
     "Unarchive card" : "Išarchyvuoti kortelę",
     "Archive card" : "Archyvuoti kortelę",
     "Delete card" : "Ištrinti kortelę",
     "Move card" : "Perkelti kortelę",
-    "Card details" : "Išsamiau apie kortelę",
     "Move card to another board" : "Perkelti kortelę į kitą lentą",
+    "seconds ago" : "prieš keletą sekundžių",
     "All boards" : "Visos lentos",
     "Archived boards" : "Archyvuotos lentos",
     "Shared with you" : "Bendrinama su jumis",
-    "New board title" : "Naujos lentos pavadinimas",
     "Edit board" : "Taisyti lentą",
     "Clone board " : "Dubliuoti lentą ",
     "Unarchive board " : "Išarchyvuoti lentą ",
@@ -181,6 +181,9 @@ OC.L10N.register(
     "An error occurred" : "Įvyko klaida",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ar tikrai norite ištrinti lentą, pavadinimu {title}? Tai ištrins visus šios lentos duomenis.",
     "Delete the board?" : "Ištrinti lentą?",
+    "Today" : "Šiandien",
+    "Tomorrow" : "Rytoj",
+    "This week" : "Šią savaitę",
     "Link to a board" : "Susieti su lenta",
     "Link to a card" : "Susieti su kortele",
     "Something went wrong" : "Kažkas nutiko",
