@@ -12,6 +12,7 @@ OC.L10N.register(
     "Cancel" : "Atcelt",
     "File already exists" : "Datne jau pastāv",
     "Do you want to overwrite it?" : "Vai tu gribi pārrakstīt to?",
+    "Hide archived cards" : "Slēpt arhivētās kartes",
     "Show archived cards" : "Rādīt arhivētās kartes",
     "Details" : "Detaļas",
     "Sharing" : "Koplietošana",
@@ -28,6 +29,7 @@ OC.L10N.register(
     "Description" : "Apraksts",
     "Attachments" : "Pielikumi",
     "Comments" : "Komentāri",
+    "Select Date" : "Izvēlieties datumu",
     "Modified" : "Mainīts",
     "Created" : "Izveidots",
     "Save" : "Saglabāt",
@@ -36,6 +38,9 @@ OC.L10N.register(
     "(group)" : "(grupa)",
     "seconds ago" : "sekundēm",
     "Shared with you" : "Koplietots ar tevi",
-    "An error occurred" : "Gadījās kļūda"
+    "An error occurred" : "Gadījās kļūda",
+    "Today" : "Šodien",
+    "Tomorrow" : "Rīt",
+    "This week" : "Šonedēļ"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
