@@ -22,16 +22,20 @@ OC.L10N.register(
     "Delete" : "Избриши",
     "Edit" : "Уреди",
     "Title" : "Наслов",
+    "Upload attachment" : "Прикачи прилог",
     "Description" : "Опис",
     "Comments" : "Коментари",
+    "Select Date" : "Избери датум",
     "Modified" : "Изменето",
-    "Upload attachment" : "Прикачи прилог",
     "Save" : "Зачувај",
     "Reply" : "Одговор",
     "Update" : "Ажурирај",
     "(group)" : "(group)",
     "seconds ago" : "пред неколку секунди",
     "Shared with you" : "Споделено со тебе",
-    "An error occurred" : "Настана грешка"
+    "An error occurred" : "Настана грешка",
+    "Today" : "Денес",
+    "Tomorrow" : "Утре",
+    "This week" : "Оваа недела"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
