@@ -9,6 +9,7 @@ OC.L10N.register(
     "Later" : "Хойшлуулах",
     "Done" : "Хийсэн",
     "Cancel" : "болиулах",
+    "Hide archived cards" : "Архивлагдсан картуудыг нуух",
     "Show archived cards" : "Архивлагдсан картуудыг харах",
     "Details" : "Дэлгэрэнгүй",
     "Sharing" : "Түгээх",
@@ -30,6 +31,9 @@ OC.L10N.register(
     "Update" : "Шинэчлэх",
     "(group)" : "(бүлэг)",
     "seconds ago" : "хоёрдахь өмнө",
-    "Shared with you" : "тантай хуваалцсан"
+    "Shared with you" : "тантай хуваалцсан",
+    "Today" : "өнөөдөр",
+    "Tomorrow" : "маргааш",
+    "This week" : "7 хоног"
 },
 "nplurals=2; plural=(n != 1);");
