@@ -16,6 +16,8 @@ OC.L10N.register(
     "Reply" : "Respondre",
     "Update" : "Metre a jorn",
     "seconds ago" : "i a qualques segondas",
-    "Shared with you" : "Shared with you"
+    "Shared with you" : "Shared with you",
+    "Today" : "Uèi",
+    "Tomorrow" : "Deman"
 },
 "nplurals=2; plural=(n > 1);");
