@@ -11,6 +11,7 @@ OC.L10N.register(
     "Comments" : "تبصرې",
     "Modified" : "د بدلون نېټه",
     "Save" : "ساتل",
-    "Shared with you" : "تاسې سره شريک شوي"
+    "Shared with you" : "تاسې سره شريک شوي",
+    "Today" : "نن"
 },
 "nplurals=2; plural=(n != 1);");
