@@ -16,9 +16,10 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro carregado excedo a directiva MAX_FILE_SIZE especificada no formulário HTML",
     "No file was uploaded" : "O ficheiro foi carregado",
     "Missing a temporary folder" : "Falta uma pasta temporária",
-    "Create new board" : "Criar novo quadro",
+    "Add board" : "Arquivar cartão",
     "Cancel" : "Cancelar",
     "File already exists" : "O ficheiro já existe",
+    "Hide archived cards" : "Esconder cartões arquivados",
     "Show archived cards" : "Mostrar cartões arquivados",
     "Details" : "Detalhes",
     "Sharing" : "Partilha",
@@ -36,20 +37,23 @@ OC.L10N.register(
     "Description" : "Descrição",
     "Attachments" : "Anexos",
     "Comments" : "Comentários",
+    "Select Date" : "Escolha a data",
     "Modified" : "Modificado",
     "Created" : "Criado",
     "Save" : "Guardar",
     "Reply" : "Resposta",
     "Update" : "Atualizar",
     "(group)" : "(grupo)",
-    "seconds ago" : "segundos atrás",
     "Archive card" : "Arquivar cartão",
     "Delete card" : "Eliminar cartão",
+    "seconds ago" : "segundos atrás",
     "Archived boards" : "Quadros arquivados",
     "Shared with you" : "Shared with you",
-    "New board title" : "Novo título de quadro",
     "Edit board" : "Editar quadro",
     "Board details" : "Detalhes do quadro",
-    "An error occurred" : "Ocorreu um erro"
+    "An error occurred" : "Ocorreu um erro",
+    "Today" : "Hoje",
+    "Tomorrow" : "Amanhã",
+    "This week" : "Esta semana"
 },
 "nplurals=2; plural=(n != 1);");
