@@ -27,6 +27,9 @@ OC.L10N.register(
     "Update" : "Actualizare",
     "(group)" : "(grup)",
     "seconds ago" : "secunde în urmă",
-    "Shared with you" : "Partajat cu tine"
+    "Shared with you" : "Partajat cu tine",
+    "Today" : "Azi",
+    "Tomorrow" : "Mâine",
+    "This week" : "Săptămâna asta"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
