@@ -15,10 +15,10 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kartela e ngarkuar tejkalon udhëzimin MAX_FILE_SIZE që qe përcaktuar te formulari HTML",
     "No file was uploaded" : "S’u ngarkua kartelë",
     "Missing a temporary folder" : "Mungon një dosje e përkohshme",
-    "Create new board" : "Krijo bord të ri",
     "Cancel" : "Anullo",
     "File already exists" : "Skedari ekziston tashmë",
     "Do you want to overwrite it?" : "Doni ta rishkruani atë?",
+    "Hide archived cards" : "Fsheh kartat e arkivuara ",
     "Show archived cards" : "Trego kartat e arkivuara",
     "Details" : "Detajet",
     "Sharing" : "Ndarje",
@@ -31,15 +31,16 @@ OC.L10N.register(
     "Edit" : "Edito",
     "Title" : "Titulli",
     "Members" : "Anëtar",
+    "Upload attachment" : "Ngarko bashkëngjitje",
     "Due date" : "Data e vendosur",
     "Remove due date" : "Hiq datën e mbarimit",
     "Description" : "Përshkrim",
     "Formatting help" : "Ndihmë formatimi",
     "Attachments" : "Bashkangjitjet",
     "Comments" : "Komentet",
+    "Select Date" : "Zgjidhni Datën",
     "Modified" : "Modifikuar ",
     "Created" : "U krijua",
-    "Upload attachment" : "Ngarko bashkëngjitje",
     "Save" : "Ruaj",
     "Reply" : "Përgjigju",
     "Update" : "Përditëso",
@@ -47,8 +48,10 @@ OC.L10N.register(
     "seconds ago" : "sekonda më parë",
     "Archived boards" : "Borde të arkivuara",
     "Shared with you" : "E ndarë me ju",
-    "New board title" : "Titull i ri bordi",
     "Edit board" : "Tabela e editimeve",
-    "Board details" : "Detajet e Tabeles "
+    "Board details" : "Detajet e Tabeles ",
+    "Today" : "Sot",
+    "Tomorrow" : "Nesër",
+    "This week" : "Këtë javë"
 },
 "nplurals=2; plural=(n != 1);");
