@@ -4,6 +4,7 @@ OC.L10N.register(
     "Finished" : "Završeno",
     "copy" : "kopiraj",
     "Done" : "Done",
+    "Add board" : "Dodaj tablu",
     "Cancel" : "Otkaži",
     "Details" : "Detalji",
     "Sharing" : "Deljenje",
@@ -21,11 +22,13 @@ OC.L10N.register(
     "Save" : "Sačuvaj",
     "Reply" : "Odgovori",
     "Update" : "Ažuriraj",
-    "seconds ago" : "pre nekoliko sekundi",
     "Archive card" : "Arhiviraj karticu",
     "Delete card" : "Obriši karticu",
     "Move card" : "Premesti karticu",
+    "seconds ago" : "pre nekoliko sekundi",
     "Shared with you" : "Shared with you",
-    "Edit board" : "Izmeni tablu"
+    "Edit board" : "Izmeni tablu",
+    "Today" : "Danas",
+    "This week" : "Ove sedmice"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
