@@ -67,6 +67,7 @@ OC.L10N.register(
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "Ändringar i <strong>Deck-appen</strong>",
     "A <strong>comment</strong> was created on a card" : "En <strong>kommentar</strong> skapades på ett kort",
+    "Upcoming cards" : "Kommande kort",
     "Personal" : "Personlig",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortet \"%s\" på \"%s\" har tilldelats dig av %s.",
     "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} har tilldelat kortet \"%s\" på \"%s\" till dig.",
@@ -98,8 +99,8 @@ OC.L10N.register(
     "No file uploaded or file size exceeds maximum of %s" : "Ingen fil uppladdad eller filstorleken överstiger max %s",
     "Personal planning and team project organization" : "Personlig planering och projekthantering för teams",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Korthögar är en kanban-liknande projekt- och organiseringsapp för arbetsgrupper i Nextcloud.\n\n\n- 📥 Lägg till uppgifter på kort och ordna dem\n- 📄 Skriv anteckningar i markdown\n- 🔖 Tilldela etiketter för organisering\n- 👥 Dela med arbetsgruppen, vänner eller familj\n- 📎 Bifoga filer och bädda in dem i markdown-anteckningarna\n- 💬 Diskutera i arbetsgruppen genom kommentarer\n- ⚡ Håll koll på ändringar i aktivitetsflödet\n- 🚀 Börja organisera din arbetsgrupp nu!",
-    "Create new board" : "Skapa ny tavla",
-    "new board" : "ny tavla",
+    "Card details" : "Kortdetaljer",
+    "Add board" : "Lägg till tavla",
     "Select the board to link to a project" : "Välj tavla att länka till ett projekt",
     "Search by board title" : "Sök efter namn på tavla",
     "Select board" : "Välj tavla",
@@ -116,11 +117,12 @@ OC.L10N.register(
     "This board is read only" : "Denna tavla är skrivskyddad",
     "Drop your files to upload" : "Släpp dina filer för att ladda upp",
     "Archived cards" : "Arkiverade kort",
-    "Add new list" : "Lägg till en ny lista",
+    "Add list" : "Lägg till lista...",
     "List name" : "Namn på lista",
     "Apply filter" : "Tillämpa filter",
     "Filter by tag" : "Filtrera efter tagg",
     "Filter by assigned user" : "Filtrera efter tilldelad användare",
+    "Unassigned" : "Ej tilldelad",
     "Filter by due date" : "Filtrera efter förfallodatum",
     "Overdue" : "Förfallen",
     "Next 24 hours" : "Nästa 24 timmar",
@@ -128,16 +130,19 @@ OC.L10N.register(
     "Next 30 days" : "Nästa 30 dagar",
     "No due date" : "Inget slutdatum",
     "Clear filter" : "Rensa filter",
+    "Hide archived cards" : "Göm arkiverade kort",
     "Show archived cards" : "Visa arkiverade kort",
     "Toggle compact mode" : "Växla kompakt läge",
     "Details" : "Detaljer",
     "Loading board" : "Läser in tavla",
+    "No lists available" : "Inga listor tillgängliga",
+    "Create a new list to add cards to this board" : "Skapa en ny lista för att lägga till kort på denna tavla",
     "Board not found" : "Tavlan hittades inte",
     "Sharing" : "Delning",
     "Tags" : "Taggar",
-    "Deleted items" : "Raderade objekt",
+    "Deleted items" : "Borttagna poster",
     "Timeline" : "Tidslinje",
-    "Deleted lists" : "Raderade listor",
+    "Deleted lists" : "Borttagna listor",
     "Undo" : "Ångra",
     "Deleted cards" : "Radera kort",
     "Share board with a user, group or circle …" : "Dela en tavla med en användare, grupp eller cirkel ...",
@@ -149,17 +154,22 @@ OC.L10N.register(
     "Can manage" : "Kan hanter",
     "Delete" : "Radera",
     "Add a new list" : "Lägg till en ny lista",
+    "Archive all cards" : "Arkivera alla kort",
     "Delete list" : "Radera lista",
     "Add card" : "Lägg till kort",
+    "Archive all cards in this list" : "Arkivera alla kort i denna lista",
     "Add a new card" : "Lägg till ett nytt kort",
     "Edit" : "Redigera",
     "Add a new tag" : "Lägg till en ny tagg",
     "title and color value must be provided" : "titel och färg måste anges",
     "Title" : "Titel",
     "Members" : "Medlemmar",
+    "Upload attachment" : "Ladda upp bilaga",
     "Add this attachment" : "Lägg till denna bilaga",
     "Delete Attachment" : "Ta bort bilaga",
     "Restore Attachment" : "Återställ bilaga",
+    "Open in sidebar view" : "Öppna i sidofältet",
+    "Open in bigger view" : "Öppna i större vy",
     "Assign a tag to this card…" : "Tilldela en tagg till det här kortet ...",
     "Assign to users" : "Tilldela till användare",
     "Assign to users/groups/circles" : "Tilldela till användare/grupper/cirklar",
@@ -177,9 +187,9 @@ OC.L10N.register(
     "Attachments" : "Bilagor",
     "Comments" : "Kommentarer",
     "Choose attachment" : "Välj bilaga",
+    "Select Date" : "Välj datum",
     "Modified" : "Ändrad",
     "Created" : "Skapat",
-    "Upload attachment" : "Ladda upp bilaga",
     "No comments yet. Begin the discussion!" : "Inga kommentarer än. Börja diskussionen!",
     "Save" : "Spara",
     "The comment cannot be empty." : "Kommentaren kan inte vara tom.",
@@ -189,22 +199,21 @@ OC.L10N.register(
     "Update" : "Uppdatera",
     "(group)" : " (grupp)",
     "(circle)" : "(cirkel)",
-    "seconds ago" : "sekunder sedan",
     "Assign to me" : "Tilldela till mig",
     "Unassign myself" : "Ta bort från mig själv",
     "Unarchive card" : "Avarkivera kort",
     "Archive card" : "Arkivera kort",
     "Delete card" : "Ta bort kort",
     "Move card" : "Flytta kort",
-    "Card details" : "Kortdetaljer",
     "Move card to another board" : "Flytta kort till en annan tavla",
     "Select a list" : "Välj en lista",
+    "seconds ago" : "sekunder sedan",
     "All boards" : "Alla tavlor",
     "Archived boards" : "Arkiverade tavlor",
     "Shared with you" : "Delad med dig",
+    "Use modal card view" : "Använd modal kort-vy",
     "Limit deck usage of groups" : "Begränsa användningen av grupper",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begränsa Deck blockerar användare som inte ingår i dessa grupper från att skapa egna tavlor. Användare kan fortfarande arbeta med tavlor som har delats med dem.",
-    "New board title" : "Ny titel för tavla",
     "Edit board" : "Ändra tavla",
     "Clone board " : "Kopiera tavla",
     "Unarchive board " : "Ta bort tavlan ur arkivet",
@@ -215,6 +224,13 @@ OC.L10N.register(
     "An error occurred" : "Ett fel uppstod",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Är du säker på att du vill radera tavla {title}? Detta kommer att radera all information från denna tavla.",
     "Delete the board?" : "Radera tavlan?",
+    "Loading filtered view" : "Laddar filtrerad vy",
+    "Today" : "Idag",
+    "Tomorrow" : "Imorgon",
+    "This week" : "Denna vecka",
+    "No due" : "Inget slut",
+    "No upcoming cards" : "Inga kommande kort",
+    "upcoming cards" : "kommande kort",
     "Link to a board" : "Länka till en tavla",
     "Link to a card" : "Länka till ett kort",
     "Something went wrong" : "Något gick fel",
