@@ -34,8 +34,8 @@ OC.L10N.register(
     "Missing a temporary folder" : "Відсутня тека для тимчасових файлів",
     "Could not write file to disk" : "Неможливо записати файл на диск",
     "A PHP extension stopped the file upload" : "Розширення PHP призупинило завантаження файлу",
-    "Create new board" : "Створити нову дошку",
-    "new board" : "нова дошка",
+    "Card details" : "Деталі картки",
+    "Add board" : "Додати дошку",
     "Select the board to link to a project" : "Виберіть дошку для прив'зки до проєкту",
     "Search by board title" : "Шукати за назвою дошки",
     "Select board" : "Вибрати дошку",
@@ -52,17 +52,19 @@ OC.L10N.register(
     "This board is read only" : "Дошка тільки для читання",
     "Drop your files to upload" : "Пересуньте файли сюди для завантаження",
     "Archived cards" : "Архівні картки",
-    "Add new list" : "Додати новий список",
+    "Add list" : "Додати список",
     "List name" : "Назва списку",
     "Apply filter" : "Відфільтрувати",
     "Filter by tag" : "Відібрати за позначками",
     "Filter by assigned user" : "Відібрати за призначеним користувачем",
+    "Unassigned" : "Скасовано призначення",
     "Filter by due date" : "Відібрати за датою завершення",
     "Overdue" : "Протерміновано",
     "Next 7 days" : "Наступні 7 днів",
     "Next 30 days" : "Наступні 30 днів",
     "No due date" : "Без дати завершення",
     "Clear filter" : "Очистити фільтр",
+    "Hide archived cards" : "Приховати архівні картки",
     "Show archived cards" : "Показати архівні картки",
     "Toggle compact mode" : "Перемкнути компактний вигляд",
     "Details" : "Деталі",
@@ -92,6 +94,7 @@ OC.L10N.register(
     "title and color value must be provided" : "потрібно зазначити назву та колір",
     "Title" : "Назва",
     "Members" : "Учасники",
+    "Upload attachment" : "Завантажити вкладення",
     "Add this attachment" : "Долучити вкладення",
     "Delete Attachment" : "Забрати вкладення",
     "Restore Attachment" : "Відновити вкладення",
@@ -112,29 +115,27 @@ OC.L10N.register(
     "Attachments" : "Вкладення",
     "Comments" : "Коментарі",
     "Choose attachment" : "Вибрати вкладення",
+    "Select Date" : "Вкажіть дату",
     "Modified" : "Змінено",
     "Created" : "Створено",
-    "Upload attachment" : "Завантажити вкладення",
     "Save" : "Зберегти",
     "In reply to" : "У відповідь",
     "Reply" : "Відповісти",
     "Update" : "Оновлення",
     "(group)" : "(група)",
     "(circle)" : "(коло)",
-    "seconds ago" : "секунд тому",
     "Assign to me" : "Призначити мені",
     "Unarchive card" : "Розархівувати картку",
     "Archive card" : "Архівувати картку",
     "Delete card" : "Вилучити картку",
     "Move card" : "Пересунути картку",
-    "Card details" : "Деталі картки",
     "Move card to another board" : "Перемістити картку до іншої дошки",
     "Select a list" : "Виберіть список",
+    "seconds ago" : "секунд тому",
     "All boards" : "Усі дошки",
     "Archived boards" : "Архівні дошки",
     "Shared with you" : "Вам надано доступ",
     "Limit deck usage of groups" : "Обмежити доступ до колоди для груп",
-    "New board title" : "Новий заголовок дошки",
     "Edit board" : "Редагувати дошку",
     "Clone board " : "Копія дошки",
     "Unarchive board " : "Розархівувати дошку",
@@ -144,6 +145,9 @@ OC.L10N.register(
     "Board {0} deleted" : "Дошку {0} вилучено",
     "An error occurred" : "Виникла помилка",
     "Delete the board?" : "Вилучити дошку?",
+    "Today" : "Сьогодні",
+    "Tomorrow" : "Завтра",
+    "This week" : "Цього тижня",
     "Link to a board" : "Прив'язати до дошки",
     "Link to a card" : "Прив'язати до картки",
     "Something went wrong" : "От халепа!",
