@@ -44,8 +44,8 @@ OC.L10N.register(
     "Could not write file to disk" : "Không thể ghi tệp lên hệ thống",
     "A PHP extension stopped the file upload" : "Một chức năng mở rộng của PHP đã dừng tải tệp lên",
     "No file uploaded or file size exceeds maximum of %s" : "Chưa có tệp nào được tải lên hoặc kích thước tệp vượt quá giới hạn của %s",
-    "Create new board" : "Tạo dự án mới",
     "Cancel" : "Hủy bỏ",
+    "Hide archived cards" : "Ẩn tác vụ đã lưu trữ",
     "Show archived cards" : "Hiện tác vụ đã lưu trữ",
     "Toggle compact mode" : "Chuyển đổi chế độ thu gọn",
     "Details" : "Thông tin",
@@ -59,27 +59,28 @@ OC.L10N.register(
     "Edit" : "Chỉnh sửa",
     "Title" : "Tên",
     "Members" : "Thành viên",
+    "Upload attachment" : "Tải lên một đính kèm",
     "Due date" : "Thời hạn",
     "Remove due date" : "Xóa thời hạn",
     "Description" : "Mô tả",
     "Formatting help" : "Định dạng trợ giúp",
     "Attachments" : "Đính kèm",
     "Comments" : "Các bình luận",
+    "Select Date" : "Chọn ngày",
     "Modified" : "Thay đổi",
     "Created" : "Đã tạo",
-    "Upload attachment" : "Tải lên một đính kèm",
     "Save" : "Lưu",
     "Reply" : "Trả l",
     "Update" : "Cập nhật",
     "(group)" : "(nhóm)",
-    "seconds ago" : "vài giây trước",
     "Assign to me" : "Phân công cho tôi",
+    "seconds ago" : "vài giây trước",
     "Archived boards" : "Dự án đã lưu trữ",
     "Shared with you" : "Đã chia sẻ với bạn",
-    "New board title" : "Tên dự án mới",
     "Edit board" : "Chỉnh sửa dự án",
     "Board details" : "Thông tin dự án",
     "An error occurred" : "Có lỗi đã xảy ra",
+    "Today" : "Hôm nay",
     "Maximum file size of {size} exceeded" : "Đã vượt quá kích thước {size} tối đa tập tin"
 },
 "nplurals=1; plural=0;");
