@@ -17,6 +17,8 @@ OC.L10N.register(
     "{user} has archived the board {before}" : "{user} 已将面板 {before} 存档",
     "You have unarchived the board {board}" : "您撤销了  {board} 存档",
     "{user} has unarchived the board {before}" : "{user} 撤销了面板 {before} 存档",
+    "You have created a new list {stack} on board {board}" : "您在 {board} 上创建了一个新列表 {stack}面板",
+    "{user} has created a new list {stack} on board {board}" : "{user} 在 {board} 上创建了一个新列表 {stack}",
     "You have renamed the card {before} to {card}" : "您将卡片 {before} 重命名为 {card}",
     "{user} has renamed the card {before} to {card}" : "{user} 将卡片 {before} 重命名为 {card}",
     "You have removed the due date of card {card}" : "您移除了到期的卡片 {card}",
@@ -74,8 +76,8 @@ OC.L10N.register(
     "No file uploaded or file size exceeds maximum of %s" : "没有文件被上传或文件大小超出最大值 %s",
     "Personal planning and team project organization" : "个人规划和团队项目组织",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "看板是集成于 Nextcloud 中的一款看板风格的任务管理工具，用于帮助进行个人计划与项目安排。\n\n\n- 📥 把您的任务添加到卡片上，并将它们有序排列\n- 📄 将您的补充说明用markdown写下来\n- 🔖 利用指派标签更好地进行筹划\n- 👥 与您的团队，朋友或家人共享\n- 📎 附加文件并将它们嵌入到您的markdown说明中\n- 💬 用评论与您的团队讨论\n- ⚡ 在活动流中紧跟变化\n- 🚀 使您的项目井井有条",
-    "Create new board" : "创建新面板",
-    "new board" : "新面板",
+    "Card details" : "卡片详情",
+    "Add board" : "添加面板",
     "Select the board to link to a project" : "选择要链接到一个项目的面板",
     "Search by board title" : "通过标题搜索面板",
     "Select board" : "选择面板",
@@ -92,11 +94,12 @@ OC.L10N.register(
     "This board is read only" : "此面板是只读的",
     "Drop your files to upload" : "拖放您的文件以上传",
     "Archived cards" : "已存档卡片",
-    "Add new list" : "添加新的列表",
+    "Add list" : "添加列表",
     "List name" : "列表名称",
     "Apply filter" : "应用过滤器",
     "Filter by tag" : "标签筛选",
     "Filter by assigned user" : "根据指定用户过滤",
+    "Unassigned" : "未分配",
     "Filter by due date" : "根据截止日期过滤",
     "Overdue" : "逾期",
     "Next 24 hours" : "未来24小时",
@@ -104,6 +107,7 @@ OC.L10N.register(
     "Next 30 days" : "下个30天",
     "No due date" : "无截止日期",
     "Clear filter" : "清空过滤器",
+    "Hide archived cards" : "隐藏已存档的卡片",
     "Show archived cards" : "显示已存档的卡片",
     "Toggle compact mode" : "切换简洁模式",
     "Details" : "详情",
@@ -124,6 +128,7 @@ OC.L10N.register(
     "Can share" : "可以共享",
     "Can manage" : "可以管理",
     "Delete" : "删除",
+    "Archive all cards" : "存档所有卡片",
     "Delete list" : "删除列表",
     "Add card" : "添加卡片",
     "Add a new card" : "添加一张新卡片",
@@ -132,6 +137,7 @@ OC.L10N.register(
     "title and color value must be provided" : "必须提供标题和颜色值",
     "Title" : "标题",
     "Members" : "会员",
+    "Upload attachment" : "上传附件",
     "Add this attachment" : "添加此附件",
     "Delete Attachment" : "删除附件",
     "Restore Attachment" : "恢复附件",
@@ -152,9 +158,9 @@ OC.L10N.register(
     "Attachments" : "附件",
     "Comments" : "评论",
     "Choose attachment" : "选择附件",
+    "Select Date" : "选择日期",
     "Modified" : "已修改",
     "Created" : "已创建",
-    "Upload attachment" : "上传附件",
     "No comments yet. Begin the discussion!" : "还没有评论。 开始讨论吧！",
     "Save" : "保存",
     "The comment cannot be empty." : "注释不能为空。",
@@ -164,20 +170,18 @@ OC.L10N.register(
     "Update" : "更新",
     "(group)" : "（组）",
     "(circle)" : "（圈子）",
-    "seconds ago" : "几秒前",
     "Assign to me" : "指派给我",
     "Unarchive card" : "恢复卡片存档",
     "Archive card" : "归档卡片",
     "Delete card" : "删除卡片",
     "Move card" : "移动卡片",
-    "Card details" : "卡片详情",
     "Move card to another board" : "将卡片移到其他面板",
+    "seconds ago" : "几秒前",
     "All boards" : "全部面板",
     "Archived boards" : "已归档面板",
     "Shared with you" : "收到的共享",
     "Limit deck usage of groups" : "限制群组的看板使用",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "非面板创建用户组的用户将不能使用受限看板。但用户仍然能够使用已共享给他们的面板工作。",
-    "New board title" : "新面板标题",
     "Edit board" : "编辑面板",
     "Clone board " : "克隆面板",
     "Unarchive board " : "解除面板归档",
@@ -188,6 +192,9 @@ OC.L10N.register(
     "An error occurred" : "发生错误",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "你确定你要删除 {title}面板吗？面板内所有数据都将因此被删除。",
     "Delete the board?" : "是否删除面板？",
+    "Today" : "今天",
+    "Tomorrow" : "明天",
+    "This week" : "本周",
     "Link to a board" : "链接到一个面板",
     "Link to a card" : "链接到一张卡片",
     "Something went wrong" : "有地方出错了",
