@@ -21,9 +21,10 @@ OC.L10N.register(
     "Could not write file to disk" : "寫入硬碟失敗",
     "A PHP extension stopped the file upload" : "一個 PHP 擴充功能終止檔案的上傳",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck是一種看板式組織工具，旨在針對與Nextcloud集成的團隊進行個人計劃和項目組織。\n\n\n- 📥 增加您的任務到card和把它們整理好\n- 📄 寫下額外的筆記在markdown\n- 🔖 分配標籤以更好地組織\n- 👥 與您的團隊，朋友或家人分享\n- 📎 附加檔案並將其嵌入到您的 markdown 描述\n- 💬 使用評論與您的團隊討論\n- ⚡ 跟踪變化在活動流程中\n- 🚀 取得您的專案組織",
+    "Add board" : "新增佈告欄",
     "Cancel" : "取消",
     "File already exists" : "檔案已存在",
-    "Add new list" : "新增清單",
+    "Add list" : "新增清單",
     "Next 7 days" : "接下來 7 天",
     "Next 30 days" : "接下來 30 天",
     "Details" : "詳細資料",
@@ -40,26 +41,30 @@ OC.L10N.register(
     "Edit" : "編輯",
     "Title" : "標題",
     "Members" : "成員",
+    "Upload attachment" : "上傳附件",
     "Assign to users" : "分派給使用者",
     "Due date" : "截止日",
     "Description" : "描述",
     "Attachments" : "附件",
     "Comments" : "意見",
+    "Select Date" : "選擇日期",
     "Modified" : "已修改",
     "Created" : "已新增",
-    "Upload attachment" : "上傳附件",
     "Save" : "儲存",
     "Reply" : "回覆",
     "Update" : "更新",
     "(group)" : "(群組)",
-    "seconds ago" : "幾秒前",
     "Assign to me" : "分派給我",
     "Archive card" : "封存卡片",
     "Delete card" : "刪除作業",
     "Move card" : "移動卡片",
+    "seconds ago" : "幾秒前",
     "Shared with you" : "與您分享",
     "Edit board" : "編輯專案",
     "An error occurred" : "發生錯誤",
+    "Today" : "今天",
+    "Tomorrow" : "明天",
+    "This week" : "本週",
     "Link to a board" : "連結到佈告欄",
     "Maximum file size of {size} exceeded" : "達到最大的檔案大小 {size} "
 },
