@@ -64,6 +64,8 @@ class BoardService {
 	private $eventDispatcher;
 	private $changeHelper;
 
+	private $boardsCache = null;
+
 	public function __construct(
 		BoardMapper $boardMapper,
 		StackMapper $stackMapper,
@@ -105,42 +107,55 @@ class BoardService {
 		$this->userId = $userId;
 	}
 
-	/**
-	 * @return array
-	 */
-	public function findAll($since = -1, $details = null) {
+	public function getUserBoards(int $since = -1, $includeArchived = true): array {
 		$userInfo = $this->getBoardPrerequisites();
-		$userBoards = $this->boardMapper->findAllByUser($userInfo['user'], null, null, $since);
-		$groupBoards = $this->boardMapper->findAllByGroups($userInfo['user'], $userInfo['groups'],null, null,  $since);
-		$circleBoards = $this->boardMapper->findAllByCircles($userInfo['user'], null, null,  $since);
-		$complete = array_merge($userBoards, $groupBoards, $circleBoards);
+		$userBoards = $this->boardMapper->findAllByUser($userInfo['user'], null, null, $since, $includeArchived);
+		$groupBoards = $this->boardMapper->findAllByGroups($userInfo['user'], $userInfo['groups'],null, null, $since, $includeArchived);
+		$circleBoards = $this->boardMapper->findAllByCircles($userInfo['user'], null, null,  $since, $includeArchived);
+		$mergedBoards = array_merge($userBoards, $groupBoards, $circleBoards);
 		$result = [];
 		/** @var Board $item */
-		foreach ($complete as &$item) {
+		foreach ($mergedBoards as &$item) {
 			if (!array_key_exists($item->getId(), $result)) {
-				$this->boardMapper->mapOwner($item);
-				if ($item->getAcl() !== null) {
-					foreach ($item->getAcl() as &$acl) {
-						$this->boardMapper->mapAcl($acl);
-					}
-				}
-				if ($details !== null) {
-					$this->enrichWithStacks($item);
-					$this->enrichWithLabels($item);
-					$this->enrichWithUsers($item);
-				}
-				$permissions = $this->permissionService->matchPermissions($item);
-				$item->setPermissions([
-					'PERMISSION_READ' => $permissions[Acl::PERMISSION_READ] ?? false,
-					'PERMISSION_EDIT' => $permissions[Acl::PERMISSION_EDIT] ?? false,
-					'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE] ?? false,
-					'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE] ?? false
-				]);
 				$result[$item->getId()] = $item;
 			}
 		}
 		return array_values($result);
 	}
+	/**
+	 * @return array
+	 */
+	public function findAll($since = -1, $details = null, $includeArchived = true) {
+		if ($this->boardsCache) {
+			return $this->boardsCache;
+		}
+		$complete = $this->getUserBoards($since, $includeArchived);
+		$result = [];
+		/** @var Board $item */
+		foreach ($complete as &$item) {
+			$this->boardMapper->mapOwner($item);
+			if ($item->getAcl() !== null) {
+				foreach ($item->getAcl() as &$acl) {
+					$this->boardMapper->mapAcl($acl);
+				}
+			}
+			if ($details !== null) {
+				$this->enrichWithStacks($item);
+				$this->enrichWithLabels($item);
+				$this->enrichWithUsers($item);
+			}
+			$permissions = $this->permissionService->matchPermissions($item);
+			$item->setPermissions([
+				'PERMISSION_READ' => $permissions[Acl::PERMISSION_READ] ?? false,
+				'PERMISSION_EDIT' => $permissions[Acl::PERMISSION_EDIT] ?? false,
+				'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE] ?? false,
+				'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE] ?? false
+			]);
+			$result[$item->getId()] = $item;
+		}
+		$this->boardsCache = $result;
+		return array_values($result);
+	}
 
 	/**
 	 * @param $boardId
@@ -151,6 +166,9 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function find($boardId) {
+		if ($this->boardsCache && isset($this->boardsCache[$boardId])) {
+			return $this->boardsCache[$boardId];
+		}
 		if (is_numeric($boardId) === false) {
 			throw new BadRequestException('board id must be a number');
 		}
@@ -172,6 +190,7 @@ class BoardService {
 			'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE] ?? false
 		]);
 		$this->enrichWithUsers($board);
+		$this->boardsCache[$board->getId()] = $board;
 		return $board;
 	}
 
@@ -331,7 +350,7 @@ class BoardService {
 			throw new BadRequestException('board id must be a number');
 		}
 
-		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_READ);
+		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_MANAGE);
 		$board = $this->find($id);
 		if ($board->getDeletedAt() > 0) {
 			throw new BadRequestException('This board has already been deleted');
@@ -360,7 +379,7 @@ class BoardService {
 			throw new BadRequestException('board id must be a number');
 		}
 
-		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_READ);
+		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_MANAGE);
 		$board = $this->find($id);
 		$board->setDeletedAt(0);
 		$board = $this->boardMapper->update($board);
@@ -387,7 +406,7 @@ class BoardService {
 			throw new BadRequestException('id must be a number');
 		}
 
-		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_READ);
+		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_MANAGE);
 		$board = $this->find($id);
 		$delete = $this->boardMapper->delete($board);
 
@@ -415,7 +434,7 @@ class BoardService {
 		}
 
 		if ($title === false || $title === null) {
-			throw new BadRequestException('color must be provided');
+			throw new BadRequestException('title must be provided');
 		}
 
 		if ($color === false || $color === null) {
