@@ -116,6 +116,11 @@ class CardService {
 		return $cards;
 	}
 
+	public function search($boardIds, $term) {
+		$cards = $this->cardMapper->search($boardIds, $term);
+		return $cards;
+	}
+
 	/**
 	 * @param $cardId
 	 * @return \OCA\Deck\Db\RelationalEntity
@@ -139,6 +144,15 @@ class CardService {
 		return $card;
 	}
 
+	public function findCalendarEntries($boardId) {
+		$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_READ);
+		$cards = $this->cardMapper->findCalendarEntries($boardId);
+		foreach ($cards as $card) {
+			$this->enrich($card);
+		}
+		return $cards;
+	}
+
 	/**
 	 * @param $title
 	 * @param $stackId
@@ -401,8 +415,11 @@ class CardService {
 		if ($card->getArchived()) {
 			throw new StatusException('Operation not allowed. This card is archived.');
 		}
+		$changes = new ChangeSet($card);
 		$card->setStackId($stackId);
 		$this->cardMapper->update($card);
+		$changes->setAfter($card);
+		$this->activityManager->triggerUpdateEvents(ActivityManager::DECK_OBJECT_CARD, $changes, ActivityManager::SUBJECT_CARD_UPDATE);
 
 		$cards = $this->cardMapper->findAll($stackId);
 		$result = [];
@@ -564,4 +581,28 @@ class CardService {
 			'\OCA\Deck\Card::onUpdate', new FTSEvent(null, ['id' => $cardId, 'card' => $card])
 		);
 	}
+
+	/**
+	 *
+	 * @return array
+	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws BadRequestException
+	 */
+	public function findAllWithDue($userId) {
+		$cards = $this->cardMapper->findAllWithDue($userId);
+		
+		return $cards;
+	}
+
+	/**
+	 *
+	 * @return array
+	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws BadRequestException
+	 */
+	public function findAssignedCards($userId) {
+		$cards = $this->cardMapper->findAssignedCards($userId);
+		
+		return $cards;
+	}
 }
